{{
File: Menu.spin
Version: 0.2

Menu object used by Test Propeller Eeprom v0.677.spin.

This object takes care of the HyperTerminal interactions, and its methods are designed
to make it easy to discern which variables store values entered by the user.
}}

OBJ

  term   : "HyperTerminal"                       ' HyperTerminal object

Pub Init                                         '' Initializes the menu object
                                                 ''
  '' Starts HyperTerminal on programming pins at 57600 bps, 8N1.
                                                 
  term.start(31, 30, 0, 57600)                   ' Start HyperTerminal object
  waitcnt(clkfreq * 2 + cnt)                     ' Give user time to click Connect

PUB Main : userKey                               '' Main menu returns userKey
                                                 ''
  '' Displays main menu, prompts user to press key, and returns key pressed (userKey). 
                                                 
  term.clear(term#SCREEN)                        ' Clear HyperTerminal screen
  term.str(@Menu)                                ' Display menu
  userKey := term.rx                             ' Get user menu selection

PUB GetLimits(startAddr, endAddr)                '' Sets values at startAddr & endAddr
                                                 ''
  '' Prompts user to enter start element and how many.  Stores start element at startAddr
  '' and calculates end element and stores it at endAddr.                                                 

  term.str(@start_element)                       ' Prompt user to pick a starting element
  long[startAddr] := term.getDec #>0<#31         ' Get value, the element index
  term.str(@how_many)                            ' Prompt user how many elements to set
  long[endAddr] := long[startAddr] + term.getDec - 1 #>0<#31  ' Get value and keep it in a valid range
   
PUB GetEeInfo(startAddr, endAddr, eeAddr)        '' Given three addresses, sets 3 variables
                                                 ''
  '' Prompts user to enter array start element, how many, and an EEPROM start address.
  '' Stores start element at startAddr, calculates end element and stores it at endAddr,
  '' and stores EEPROM start address at eeAddr.

  GetLimits(startAddr, endAddr)
  term.str(@Eeprom_Start)
  long[eeAddr] := term.getDec

PUB GetElement(i)                                '' Returns value entered by user

  '' Given an index, displays the index and returns value entered by user.

  Index(i)                                       '' Display index and prompt
  result := term.getDec                          '' Get user entered value & return

PUB DisplayElement(value, i)                     '' Display element
                                                 ''
  '' Displays array element given its value and index.
                                                 
  Index(i)                                       '' Display index 
  term.Dec(value)                                '' Display value

PUB Index(i)                                     '' Displays index value & prompt
                                                 ''
  term.Cr
  term.Dec(i)                                    ' Display array index
  term.Str(String(" > "))                        ' Display prompt/separator

PUB KeyPress                                     '' Prompts for and returns key press
                                                 ''
  term.cr
  term.str(@press)                               ' Instruct user to press any key
  result := term.rx                              ' Wait for key press

PUB TryAgain                                     '' Displays "Try again" message
                                                 ''
  term.str(@try_again)

PUB EeParams(eeAddr, countAddr, sizeAddr)        '' Sets variable values at 3 addresses
                                                 ''
  '' Prompts user for EEPROM start address, number of values to be entered and their
  '' variable size.  Stores results at variables pointed to by eeAddr, countAddr and
  '' sizeAddr.

  term.str(@eeprom_start)
  long[eeAddr] := term.getDec
  term.str(@how_many)
  long[countAddr] := term.getDec
  term.str(@size)
  long[sizeAddr] := term.getDec
  

PUB DisplayElement2(value, i)                    '' Display a value and index
                                                 ''
  term.Cr
  term.Dec(i)                                    ' Display array index
  term.Str(String(" > "))                        ' Display prompt/separator
  term.Dec(value)
  term.Cr

DAT

' User interface text.

Menu
              byte "MENU"
              byte 10, 13, "C = Clear Array"
              byte 10, 13, "D = Display array"
              byte 10, 13, "M = Modify array elements"
              byte 10, 13, "B = Backup array to EEPROM"
              byte 10, 13, "L = Load array from EEPROM"
              byte 10, 13, "T = Copy array elements To EEPROM address"
              byte 10, 13, "F = Copy From EEPROM address to array elements"
              byte 10, 13, "W = Write individual values to EEPROM"
              byte 10, 13, "R = Read individual values from EEPROM"
              byte 10, 13, ">", 0

start_element byte 10, 13, "Start element (0..31) > ", 0
how_many      byte 10, 13, "How many? > ", 0
eeprom_start  byte 10, 13, "EEPROM start address > ", 0
add_elements  byte 10, 13, "Enter values...", 13, 0
press         byte         "Press any key...>", 0
size          byte 10, 13, "1-byte, 2-word, 4-long", 10, 13, "size > ", 0
done          byte 10, 13, "Done.  ", 0
try_again     byte 10, 13, "Not a menu choice, try again...", 0